# LOOBins

**L**iving **O**ff the **O**rchard: macOS Binaries (LOOBins) is designed to provide detailed information on various built-in macOS binaries and how they can be used by threat actors for malicious purposes. This list does not include overlapping Unix binaries that are detailed in [GTFOBins](https://gtfobins.github.io).

